Documentation
¶
Overview ¶
Deprecated: Please note, this package has been deprecated. A replacement package is available github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/addons/armaddons(https://pkg.go.dev/github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/addons/armaddons). We strongly encourage you to upgrade to continue receiving updates. See [Migration Guide](https://aka.ms/azsdk/golang/t2/migration) for guidance on upgrading. Refer to our [deprecation policy](https://azure.github.io/azure-sdk/policies_support.html) for more details.
Package addons implements the Azure ARM Addons service API version 2017-05-15.
The service for managing third party addons.
Index ¶
- Constants
- func UserAgent() string
- func Version() string
- type BaseClient
- type CanonicalSupportPlanProperties
- type CanonicalSupportPlanResponseEnvelope
- type CanonicalSupportPlanStatusItem
- type CanonicalSupportPlanTypesClient
- func (client CanonicalSupportPlanTypesClient) Get(ctx context.Context, providerName string) (result ListCanonicalSupportPlanStatusItem, err error)
- func (client CanonicalSupportPlanTypesClient) GetPreparer(ctx context.Context, providerName string) (*http.Request, error)
- func (client CanonicalSupportPlanTypesClient) GetResponder(resp *http.Response) (result ListCanonicalSupportPlanStatusItem, err error)
- func (client CanonicalSupportPlanTypesClient) GetSender(req *http.Request) (*http.Response, error)
- type ErrorDefinition
- type ListCanonicalSupportPlanStatusItem
- type ListOperationsDefinition
- type OperationsClient
- func (client OperationsClient) List(ctx context.Context) (result ListOperationsDefinition, err error)
- func (client OperationsClient) ListPreparer(ctx context.Context) (*http.Request, error)
- func (client OperationsClient) ListResponder(resp *http.Response) (result ListOperationsDefinition, err error)
- func (client OperationsClient) ListSender(req *http.Request) (*http.Response, error)
- type OperationsDefinition
- type OperationsDisplayDefinition
- type PlanTypeName
- type ProvisioningState
- type SupportPlanType
- type SupportPlanTypesClient
- func (client SupportPlanTypesClient) CreateOrUpdate(ctx context.Context, providerName string, planTypeName PlanTypeName) (result SupportPlanTypesCreateOrUpdateFuture, err error)
- func (client SupportPlanTypesClient) CreateOrUpdatePreparer(ctx context.Context, providerName string, planTypeName PlanTypeName) (*http.Request, error)
- func (client SupportPlanTypesClient) CreateOrUpdateResponder(resp *http.Response) (result CanonicalSupportPlanResponseEnvelope, err error)
- func (client SupportPlanTypesClient) CreateOrUpdateSender(req *http.Request) (future SupportPlanTypesCreateOrUpdateFuture, err error)
- func (client SupportPlanTypesClient) Delete(ctx context.Context, providerName string, planTypeName PlanTypeName) (result SupportPlanTypesDeleteFuture, err error)
- func (client SupportPlanTypesClient) DeletePreparer(ctx context.Context, providerName string, planTypeName PlanTypeName) (*http.Request, error)
- func (client SupportPlanTypesClient) DeleteResponder(resp *http.Response) (result CanonicalSupportPlanResponseEnvelope, err error)
- func (client SupportPlanTypesClient) DeleteSender(req *http.Request) (future SupportPlanTypesDeleteFuture, err error)
- func (client SupportPlanTypesClient) Get(ctx context.Context, providerName string, planTypeName PlanTypeName) (result CanonicalSupportPlanResponseEnvelope, err error)
- func (client SupportPlanTypesClient) GetPreparer(ctx context.Context, providerName string, planTypeName PlanTypeName) (*http.Request, error)
- func (client SupportPlanTypesClient) GetResponder(resp *http.Response) (result CanonicalSupportPlanResponseEnvelope, err error)
- func (client SupportPlanTypesClient) GetSender(req *http.Request) (*http.Response, error)
- type SupportPlanTypesCreateOrUpdateFuture
- type SupportPlanTypesDeleteFuture
Constants ¶
const (
// DefaultBaseURI is the default URI used for the service Addons
DefaultBaseURI = "https://management.azure.com"
)
Variables ¶
This section is empty.
Functions ¶
func UserAgent ¶
func UserAgent() string
UserAgent returns the UserAgent string to use when sending http.Requests.
func Version ¶
func Version() string
Version returns the semantic version (see http://semver.org) of the client.
Types ¶
type BaseClient ¶
BaseClient is the base client for Addons.
func New ¶
func New(subscriptionID string) BaseClient
New creates an instance of the BaseClient client.
func NewWithBaseURI ¶
func NewWithBaseURI(baseURI string, subscriptionID string) BaseClient
NewWithBaseURI creates an instance of the BaseClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
type CanonicalSupportPlanProperties ¶
type CanonicalSupportPlanProperties struct {
// ProvisioningState - The provisioning state of the resource. Possible values include: 'Succeeded', 'Failed', 'Cancelled', 'Purchasing', 'Downgrading', 'Cancelling', 'Upgrading'
ProvisioningState ProvisioningState `json:"provisioningState,omitempty"`
}
CanonicalSupportPlanProperties the properties of the Canonical support plan.
type CanonicalSupportPlanResponseEnvelope ¶
type CanonicalSupportPlanResponseEnvelope struct {
autorest.Response `json:"-"`
// ID - READ-ONLY; The id of the ARM resource, e.g. "/subscriptions/{id}/providers/Microsoft.Addons/supportProvider/{supportProviderName}/supportPlanTypes/{planTypeName}".
ID *string `json:"id,omitempty"`
// Name - READ-ONLY; The name of the Canonical support plan, i.e. "essential", "standard" or "advanced".
Name *string `json:"name,omitempty"`
// Type - READ-ONLY; Microsoft.Addons/supportProvider
Type *string `json:"type,omitempty"`
// CanonicalSupportPlanProperties - Describes Canonical support plan type and status.
*CanonicalSupportPlanProperties `json:"properties,omitempty"`
}
CanonicalSupportPlanResponseEnvelope the status of the Canonical support plan.
func (CanonicalSupportPlanResponseEnvelope) MarshalJSON ¶
func (cspre CanonicalSupportPlanResponseEnvelope) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for CanonicalSupportPlanResponseEnvelope.
func (*CanonicalSupportPlanResponseEnvelope) UnmarshalJSON ¶
func (cspre *CanonicalSupportPlanResponseEnvelope) UnmarshalJSON(body []byte) error
UnmarshalJSON is the custom unmarshaler for CanonicalSupportPlanResponseEnvelope struct.
type CanonicalSupportPlanStatusItem ¶
type CanonicalSupportPlanStatusItem struct {
// SupportPlanType - Support plan type. Possible values include: 'SupportPlanTypeEssential', 'SupportPlanTypeStandard', 'SupportPlanTypeAdvanced'
SupportPlanType SupportPlanType `json:"supportPlanType,omitempty"`
// Enabled - Whether the support plan is enabled for this subscription.
Enabled *bool `json:"enabled,omitempty"`
// WillEmitOneTimeChargeWhenEnabled - This indicates that when this support plan is enabled if AddonsRP will emit a one-time charge.
WillEmitOneTimeChargeWhenEnabled *bool `json:"willEmitOneTimeChargeWhenEnabled,omitempty"`
// WillEmitOneTimeChargeIfReEnabled - This indicates that when this support plan is cancelled and then enabled that AddonsRP will emit a one-time charge.
WillEmitOneTimeChargeIfReEnabled *bool `json:"willEmitOneTimeChargeIfReEnabled,omitempty"`
}
CanonicalSupportPlanStatusItem ...
type CanonicalSupportPlanTypesClient ¶
type CanonicalSupportPlanTypesClient struct {
BaseClient
}
CanonicalSupportPlanTypesClient is the the service for managing third party addons.
func NewCanonicalSupportPlanTypesClient ¶
func NewCanonicalSupportPlanTypesClient(subscriptionID string) CanonicalSupportPlanTypesClient
NewCanonicalSupportPlanTypesClient creates an instance of the CanonicalSupportPlanTypesClient client.
func NewCanonicalSupportPlanTypesClientWithBaseURI ¶
func NewCanonicalSupportPlanTypesClientWithBaseURI(baseURI string, subscriptionID string) CanonicalSupportPlanTypesClient
NewCanonicalSupportPlanTypesClientWithBaseURI creates an instance of the CanonicalSupportPlanTypesClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
func (CanonicalSupportPlanTypesClient) Get ¶
func (client CanonicalSupportPlanTypesClient) Get(ctx context.Context, providerName string) (result ListCanonicalSupportPlanStatusItem, err error)
Get returns the Canonical Support Plans as well as whether they are enabled or not for the subscription. Parameters: providerName - the support plan type. For now the only valid type is "canonical".
func (CanonicalSupportPlanTypesClient) GetPreparer ¶
func (client CanonicalSupportPlanTypesClient) GetPreparer(ctx context.Context, providerName string) (*http.Request, error)
GetPreparer prepares the Get request.
func (CanonicalSupportPlanTypesClient) GetResponder ¶
func (client CanonicalSupportPlanTypesClient) GetResponder(resp *http.Response) (result ListCanonicalSupportPlanStatusItem, err error)
GetResponder handles the response to the Get request. The method always closes the http.Response Body.
type ErrorDefinition ¶
type ErrorDefinition struct {
// Message - Description of the error.
Message *string `json:"message,omitempty"`
// Code - Service specific error code which serves as the substatus for the HTTP error code.
Code *int32 `json:"code,omitempty"`
}
ErrorDefinition error description and code explaining why an operation failed.
type ListCanonicalSupportPlanStatusItem ¶
type ListCanonicalSupportPlanStatusItem struct {
autorest.Response `json:"-"`
Value *[]CanonicalSupportPlanStatusItem `json:"value,omitempty"`
}
ListCanonicalSupportPlanStatusItem ...
type ListOperationsDefinition ¶
type ListOperationsDefinition struct {
autorest.Response `json:"-"`
Value *[]OperationsDefinition `json:"value,omitempty"`
}
ListOperationsDefinition ...
type OperationsClient ¶
type OperationsClient struct {
BaseClient
}
OperationsClient is the the service for managing third party addons.
func NewOperationsClient ¶
func NewOperationsClient(subscriptionID string) OperationsClient
NewOperationsClient creates an instance of the OperationsClient client.
func NewOperationsClientWithBaseURI ¶
func NewOperationsClientWithBaseURI(baseURI string, subscriptionID string) OperationsClient
NewOperationsClientWithBaseURI creates an instance of the OperationsClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
func (OperationsClient) List ¶
func (client OperationsClient) List(ctx context.Context) (result ListOperationsDefinition, err error)
List lists all of the available Addons RP operations.
func (OperationsClient) ListPreparer ¶
ListPreparer prepares the List request.
func (OperationsClient) ListResponder ¶
func (client OperationsClient) ListResponder(resp *http.Response) (result ListOperationsDefinition, err error)
ListResponder handles the response to the List request. The method always closes the http.Response Body.
func (OperationsClient) ListSender ¶
ListSender sends the List request. The method will close the http.Response Body if it receives an error.
type OperationsDefinition ¶
type OperationsDefinition struct {
// Name - Name of the operation.
Name *string `json:"name,omitempty"`
// Display - Display object with properties of the operation.
Display *OperationsDisplayDefinition `json:"display,omitempty"`
}
OperationsDefinition definition object with the name and properties of an operation.
type OperationsDisplayDefinition ¶
type OperationsDisplayDefinition struct {
// Provider - Resource provider of the operation.
Provider *string `json:"provider,omitempty"`
// Resource - Resource for the operation.
Resource *string `json:"resource,omitempty"`
// Operation - Short description of the operation.
Operation *string `json:"operation,omitempty"`
// Description - Description of the operation.
Description *string `json:"description,omitempty"`
}
OperationsDisplayDefinition display object with properties of the operation.
type PlanTypeName ¶
type PlanTypeName string
PlanTypeName enumerates the values for plan type name.
const ( // Advanced ... Advanced PlanTypeName = "Advanced" // Essential ... Essential PlanTypeName = "Essential" // Standard ... Standard PlanTypeName = "Standard" )
func PossiblePlanTypeNameValues ¶
func PossiblePlanTypeNameValues() []PlanTypeName
PossiblePlanTypeNameValues returns an array of possible values for the PlanTypeName const type.
type ProvisioningState ¶
type ProvisioningState string
ProvisioningState enumerates the values for provisioning state.
const ( // Cancelled ... Cancelled ProvisioningState = "Cancelled" // Cancelling ... Cancelling ProvisioningState = "Cancelling" // Downgrading ... Downgrading ProvisioningState = "Downgrading" // Failed ... Failed ProvisioningState = "Failed" // Purchasing ... Purchasing ProvisioningState = "Purchasing" // Succeeded ... Succeeded ProvisioningState = "Succeeded" // Upgrading ... Upgrading ProvisioningState = "Upgrading" )
func PossibleProvisioningStateValues ¶
func PossibleProvisioningStateValues() []ProvisioningState
PossibleProvisioningStateValues returns an array of possible values for the ProvisioningState const type.
type SupportPlanType ¶
type SupportPlanType string
SupportPlanType enumerates the values for support plan type.
const ( // SupportPlanTypeAdvanced ... SupportPlanTypeAdvanced SupportPlanType = "advanced" // SupportPlanTypeEssential ... SupportPlanTypeEssential SupportPlanType = "essential" // SupportPlanTypeStandard ... SupportPlanTypeStandard SupportPlanType = "standard" )
func PossibleSupportPlanTypeValues ¶
func PossibleSupportPlanTypeValues() []SupportPlanType
PossibleSupportPlanTypeValues returns an array of possible values for the SupportPlanType const type.
type SupportPlanTypesClient ¶
type SupportPlanTypesClient struct {
BaseClient
}
SupportPlanTypesClient is the the service for managing third party addons.
func NewSupportPlanTypesClient ¶
func NewSupportPlanTypesClient(subscriptionID string) SupportPlanTypesClient
NewSupportPlanTypesClient creates an instance of the SupportPlanTypesClient client.
func NewSupportPlanTypesClientWithBaseURI ¶
func NewSupportPlanTypesClientWithBaseURI(baseURI string, subscriptionID string) SupportPlanTypesClient
NewSupportPlanTypesClientWithBaseURI creates an instance of the SupportPlanTypesClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
func (SupportPlanTypesClient) CreateOrUpdate ¶
func (client SupportPlanTypesClient) CreateOrUpdate(ctx context.Context, providerName string, planTypeName PlanTypeName) (result SupportPlanTypesCreateOrUpdateFuture, err error)
CreateOrUpdate creates or updates the Canonical support plan of type {type} for the subscription. Parameters: providerName - the support plan type. For now the only valid type is "canonical". planTypeName - the Canonical support plan type.
func (SupportPlanTypesClient) CreateOrUpdatePreparer ¶
func (client SupportPlanTypesClient) CreateOrUpdatePreparer(ctx context.Context, providerName string, planTypeName PlanTypeName) (*http.Request, error)
CreateOrUpdatePreparer prepares the CreateOrUpdate request.
func (SupportPlanTypesClient) CreateOrUpdateResponder ¶
func (client SupportPlanTypesClient) CreateOrUpdateResponder(resp *http.Response) (result CanonicalSupportPlanResponseEnvelope, err error)
CreateOrUpdateResponder handles the response to the CreateOrUpdate request. The method always closes the http.Response Body.
func (SupportPlanTypesClient) CreateOrUpdateSender ¶
func (client SupportPlanTypesClient) CreateOrUpdateSender(req *http.Request) (future SupportPlanTypesCreateOrUpdateFuture, err error)
CreateOrUpdateSender sends the CreateOrUpdate request. The method will close the http.Response Body if it receives an error.
func (SupportPlanTypesClient) Delete ¶
func (client SupportPlanTypesClient) Delete(ctx context.Context, providerName string, planTypeName PlanTypeName) (result SupportPlanTypesDeleteFuture, err error)
Delete cancels the Canonical support plan of type {type} for the subscription. Parameters: providerName - the support plan type. For now the only valid type is "canonical". planTypeName - the Canonical support plan type.
func (SupportPlanTypesClient) DeletePreparer ¶
func (client SupportPlanTypesClient) DeletePreparer(ctx context.Context, providerName string, planTypeName PlanTypeName) (*http.Request, error)
DeletePreparer prepares the Delete request.
func (SupportPlanTypesClient) DeleteResponder ¶
func (client SupportPlanTypesClient) DeleteResponder(resp *http.Response) (result CanonicalSupportPlanResponseEnvelope, err error)
DeleteResponder handles the response to the Delete request. The method always closes the http.Response Body.
func (SupportPlanTypesClient) DeleteSender ¶
func (client SupportPlanTypesClient) DeleteSender(req *http.Request) (future SupportPlanTypesDeleteFuture, err error)
DeleteSender sends the Delete request. The method will close the http.Response Body if it receives an error.
func (SupportPlanTypesClient) Get ¶
func (client SupportPlanTypesClient) Get(ctx context.Context, providerName string, planTypeName PlanTypeName) (result CanonicalSupportPlanResponseEnvelope, err error)
Get returns whether or not the canonical support plan of type {type} is enabled for the subscription. Parameters: providerName - the support plan type. For now the only valid type is "canonical". planTypeName - the Canonical support plan type.
func (SupportPlanTypesClient) GetPreparer ¶
func (client SupportPlanTypesClient) GetPreparer(ctx context.Context, providerName string, planTypeName PlanTypeName) (*http.Request, error)
GetPreparer prepares the Get request.
func (SupportPlanTypesClient) GetResponder ¶
func (client SupportPlanTypesClient) GetResponder(resp *http.Response) (result CanonicalSupportPlanResponseEnvelope, err error)
GetResponder handles the response to the Get request. The method always closes the http.Response Body.
type SupportPlanTypesCreateOrUpdateFuture ¶
type SupportPlanTypesCreateOrUpdateFuture struct {
azure.FutureAPI
// Result returns the result of the asynchronous operation.
// If the operation has not completed it will return an error.
Result func(SupportPlanTypesClient) (CanonicalSupportPlanResponseEnvelope, error)
}
SupportPlanTypesCreateOrUpdateFuture an abstraction for monitoring and retrieving the results of a long-running operation.
func (*SupportPlanTypesCreateOrUpdateFuture) UnmarshalJSON ¶
func (future *SupportPlanTypesCreateOrUpdateFuture) UnmarshalJSON(body []byte) error
UnmarshalJSON is the custom unmarshaller for CreateFuture.
type SupportPlanTypesDeleteFuture ¶
type SupportPlanTypesDeleteFuture struct {
azure.FutureAPI
// Result returns the result of the asynchronous operation.
// If the operation has not completed it will return an error.
Result func(SupportPlanTypesClient) (CanonicalSupportPlanResponseEnvelope, error)
}
SupportPlanTypesDeleteFuture an abstraction for monitoring and retrieving the results of a long-running operation.
func (*SupportPlanTypesDeleteFuture) UnmarshalJSON ¶
func (future *SupportPlanTypesDeleteFuture) UnmarshalJSON(body []byte) error
UnmarshalJSON is the custom unmarshaller for CreateFuture.